@@ -185,7 +185,7 @@ int main(int argc, char** argv) {
 
     /* First, fill the entire array with zeros, using a blocking I/O.
        Every process writes a subarray of size NY * myNX */
-    buf    = (int**) malloc(myNX * sizeof(int*));
+    buf    = (int**) malloc(sizeof(int*) * myNX);
     buf[0] = (int*)  calloc(NY * myNX, sizeof(int));
     start[0] = 0;   start[1] = myOff;
     count[0] = NY;  count[1] = myNX;
@@ -197,12 +197,12 @@ int main(int argc, char** argv) {
     /* initialize the buffer with rank ID. Also make the case interesting,
        by allocating buffers separately */
     for (i=0; i<myNX; i++) {
-        buf[i] = (int*) malloc(NY * sizeof(int));
+        buf[i] = (int*) malloc(sizeof(int) * NY);
         for (j=0; j<NY; j++) buf[i][j] = rank+10;
     }
 
-    reqs = (int*) malloc(myNX * sizeof(int));
-    sts  = (int*) malloc(myNX * sizeof(int));
+    reqs = (int*) malloc(sizeof(int) * myNX);
+    sts  = (int*) malloc(sizeof(int) * myNX);
 
     /* each proc writes myNX columns of the 2D array, block_len controls the
        number of contiguous columns at a time */
@@ -272,15 +272,15 @@ int main(int argc, char** argv) {
     ERR
 
     /* initialize the buffer with -1, so a read error can be pinpointed */
-    buf    = (int**) malloc(myNX * sizeof(int*));
-    buf[0] = (int*)  malloc(global_ny * myNX * sizeof(int));
+    buf    = (int**) malloc(sizeof(int*) * myNX);
+    buf[0] = (int*)  malloc(sizeof(int) * global_ny * myNX);
     for (i=0; i<myNX; i++) {
         if (i > 0) buf[i] = buf[i-1] + global_ny;
         for (j=0; j<global_ny; j++) buf[i][j] = -1;
     }
 
-    reqs = (int*) malloc(myNX * sizeof(int));
-    sts  = (int*) malloc(myNX * sizeof(int));
+    reqs = (int*) malloc(sizeof(int) * myNX);
+    sts  = (int*) malloc(sizeof(int) * myNX);
 
     /* each proc reads myNX columns of the 2D array, block_len controls the
        number of contiguous columns at a time */
