@@ -154,7 +154,7 @@ pnetcdf_io(MPI_Comm comm, char *filename, int cmode, int len)
 
     /* allocate buffer and initialize with non-zero numbers */
     for (i=0; i<NUM_VARS; i++) {
-        buf[i] = (int *) malloc(bufsize * sizeof(int));
+        buf[i] = (int *) malloc(sizeof(int) * bufsize);
         for (j=0; j<bufsize; j++) buf[i][j] = rank * i + 123 + j;
     }
 
