@@ -173,11 +173,11 @@ int main(int argc, char **argv)
 
     if (verbose && rank == 0) printf("%s: example of using vard APIs to write/read two variables\n",__FILE__);
 
-    buf[0] = (int*)malloc(NY * NX * sizeof(int));
+    buf[0] = (int*)malloc(sizeof(int) * NY * NX);
     for (j=0; j<NY; j++) for (i=0; i<NX; i++)
         buf[0][j*NX+i] = rank*100 + j*10 + i;
 
-    buf[1] = (int*)malloc(NY * NX * sizeof(int));
+    buf[1] = (int*)malloc(sizeof(int) * NY * NX);
     for (j=0; j<NY; j++) for (i=0; i<NX; i++)
         buf[1][j*NX+i] = 1000 + rank*100 + j*10 + i;
 
