@@ -76,9 +76,6 @@
           integer*8 malloc_size, sum_size
           logical verbose
           integer dummy, info
-          logical                 flag, bb_enable
-          character*(MPI_MAX_INFO_VAL)     hint
-          integer                 infoused
 
           call MPI_Init(err)
           call MPI_Comm_rank(MPI_COMM_WORLD, rank, err)
@@ -109,18 +106,6 @@
      +                       info, ncid)
           call check(err, 'In nfmpi_create: ')
 
-          ! Determine if burst buffer driver is being used
-          bb_enable = .FALSE.
-          err = nfmpi_inq_file_info(ncid, infoused)
-          if (err .eq. NF_NOERR) then
-              call MPI_Info_get(infoused, "nc_burst_buf",
-     +          MPI_MAX_INFO_VAL, hint, flag, err)
-              if (flag) then
-                  bb_enable = (hint .eq. 'enable')
-              endif
-              call MPI_Info_free(infoused, err);
-          endif
-
           call MPI_Info_free(info, err)
 
           ! the global array is NX * (NY * nprocs) */
@@ -157,11 +142,8 @@
           call check(err, 'In nfmpi_put_vara_int_all: ')
 
           ! Flush the buffer to reveal potential error
-          if (bb_enable) then
-              if (err .eq. NF_NOERR) then
-                  err = nfmpi_flush(ncid)
-              endif
-          endif
+          err = nfmpi_flush(ncid)
+          call check(err, 'In nfmpi_flush: ')
 
           ! initialize the buffer with rank ID
           do i=1, NY
