@@ -7,8 +7,8 @@
 ! $Id$
 
 !
-! This example sets two PnetCDF hints:
-!    nc_header_align_size and nc_var_align_size
+! This example sets PnetCDF hint:
+!    nc_var_align_size
 ! and prints the hint values as well as the header size, header extent, and
 ! two variables' starting file offsets.
 !
@@ -18,7 +18,6 @@
 !
 !    % mpiexec -n 4 ./hints /pvfs2/wkliao/testfile.nc
 !
-!    nc_header_align_size      set to = 1024
 !    nc_var_align_size         set to = 512
 !    nc_header_read_chunk_size set to = 256
 !    header size                      = 252
@@ -55,9 +54,8 @@
           logical flag
           integer(kind=MPI_OFFSET_KIND) header_size, header_extent
           integer(kind=MPI_OFFSET_KIND) var_zy_start, var_yx_start
-          integer(kind=MPI_OFFSET_KIND) h_align, v_align, h_chunk
+          integer(kind=MPI_OFFSET_KIND) v_align, h_chunk
 
-          h_align=-1
           v_align=-1
           h_chunk=-1
 
@@ -73,13 +71,6 @@
           err = nf90mpi_inq_file_info(ncid, info_used)
           call check(err, 'In nf90mpi_inq_file_info : ')
 
-          call MPI_Info_get_valuelen(info_used, "nc_header_align_size", &
-                                     len, flag, err)
-          if (flag) then
-              call MPI_Info_get(info_used, "nc_header_align_size", &
-                                len+1, value, flag, err)
-              read(value, '(i16)') h_align
-          endif
           call MPI_Info_get_valuelen(info_used, "nc_var_align_size", &
                                      len, flag, err)
           if (flag) then
@@ -97,11 +88,6 @@
           endif
           call MPI_Info_free(info_used, err)
 
-          if (h_align .EQ. -1) then
-              print*,"nc_header_align_size      is NOT set"
-          else
-              print*,"nc_header_align_size      set to = ", h_align
-          endif
           if (v_align .EQ. -1) then
               print*,"nc_var_align_size         is NOT set"
           else
@@ -176,7 +162,6 @@
       call MPI_Bcast(filename, 256, MPI_CHARACTER, 0, MPI_COMM_WORLD, err)
 
       call MPI_Info_create(info, err)
-      call MPI_Info_set(info, "nc_header_align_size",      "1024", err)
       call MPI_Info_set(info, "nc_var_align_size",         "512",  err)
       call MPI_Info_set(info, "nc_header_read_chunk_size", "256",  err)
       ! note that set the above values to 1 to disable the alignment
