@@ -815,7 +815,7 @@ ncmpi_open(MPI_Comm    comm,
 
     /* allocate chunk size for pncp->vars[] */
     nalloc = PNETCDF_RNDUP(pncp->nvars, PNC_VARS_CHUNK);
-    pncp->vars = NCI_Malloc(nalloc * sizeof(PNC_var));
+    pncp->vars = NCI_Malloc(sizeof(PNC_var) * nalloc);
     if (pncp->vars == NULL) {
         DEBUG_ASSIGN_ERROR(err, NC_ENOMEM)
         goto fn_exit;
@@ -835,10 +835,10 @@ ncmpi_open(MPI_Comm    comm,
 
         if (ndims > 0) {
             pncp->vars[i].shape = (MPI_Offset*)
-                                  NCI_Malloc(ndims * SIZEOF_MPI_OFFSET);
+                                  NCI_Malloc(sizeof(MPI_Offset) * ndims);
             if (ndims > max_ndims) { /* avoid repeated malloc */
                 if (dimids == DIMIDS) dimids = NULL;
-                dimids = (int*) NCI_Realloc(dimids, ndims * SIZEOF_INT);
+                dimids = (int*) NCI_Realloc(dimids, sizeof(int) * ndims);
                 max_ndims = ndims;
             }
             err = driver->inq_var(pncp->ncp, i, NULL, NULL, NULL,
@@ -1238,10 +1238,16 @@ ncmpi_inq_file_format(const char *filename,
             DEBUG_RETURN_ERROR(NC_EFILE)
         }
     }
-    /* get first 8 bytes of file */
+    /* get first 8 bytes of file, which contains the file signature */
+    errno = 0;
     rlen = read(fd, signature, 8);
     if (rlen != 8) {
         close(fd); /* ignore error */
+        if (rlen == 0 && errno == 0)
+            fprintf(stderr, "Error: empty file %s\n", filename);
+        else
+            fprintf(stderr, "Error: fail to read signature of file %s\n",
+                    filename);
         DEBUG_RETURN_ERROR(NC_EFILE)
     }
     if (close(fd) == -1) {
