@@ -33,14 +33,14 @@ int ncbbio_log_create(NC_bb* ncbbp,
     char procname[MPI_MAX_PROCESSOR_NAME];
     char *abspath, *fname, *path, *fdir = NULL;
     char *logbasep = ".";
-#ifdef PNETCDF_PROFILING
+#if defined(PNETCDF_PROFILING) && (PNETCDF_PROFILING == 1)
     double t1, t2;
 #endif
     DIR *logdir;
     ssize_t headersize;
     NC_bb_metadataheader *headerp;
 
-#ifdef PNETCDF_PROFILING
+#if defined(PNETCDF_PROFILING) && (PNETCDF_PROFILING == 1)
     t1 = MPI_Wtime();
 #endif
 
@@ -87,7 +87,7 @@ int ncbbio_log_create(NC_bb* ncbbp,
     }
     else {
         size_t i = strlen(path);
-        fdir = (char*)NCI_Malloc((i + 1) * sizeof(char));
+        fdir = (char*)NCI_Malloc(sizeof(char) * (i + 1));
         strncpy(fdir, path, i + 1);
         /* Search for first '\' from the back */
         for (i--; i > -1; i--) {
@@ -194,7 +194,7 @@ int ncbbio_log_create(NC_bb* ncbbp,
 
     /* Set log file descriptor to NULL */
 
-#ifdef PNETCDF_PROFILING
+#if defined(PNETCDF_PROFILING) && (PNETCDF_PROFILING == 1)
     /* Performance counters */
     ncbbp->total_data = 0;
     ncbbp->total_meta = 0;
@@ -296,7 +296,7 @@ int ncbbio_log_create(NC_bb* ncbbp,
 
     ncbbp->datalogsize = 8;
 
-#ifdef PNETCDF_PROFILING
+#if defined(PNETCDF_PROFILING) && (PNETCDF_PROFILING == 1)
     t2 = MPI_Wtime();
     ncbbp->total_time += t2 - t1;
     ncbbp->create_time += t2 - t1;
@@ -317,7 +317,7 @@ int ncbbio_log_enddef(NC_bb *ncbbp)
     int err;
     NC_bb_metadataheader *headerp;
 
-#ifdef PNETCDF_PROFILING
+#if defined(PNETCDF_PROFILING) && (PNETCDF_PROFILING == 1)
     double t1, t2;
     t1 = MPI_Wtime();
 #endif
@@ -345,7 +345,7 @@ int ncbbio_log_enddef(NC_bb *ncbbp)
         }
     }
 
-#ifdef PNETCDF_PROFILING
+#if defined(PNETCDF_PROFILING) && (PNETCDF_PROFILING == 1)
     t2 = MPI_Wtime();
     ncbbp->total_time += t2 - t1;
     ncbbp->enddef_time += t2 - t1;
@@ -365,7 +365,7 @@ int ncbbio_log_close(NC_bb *ncbbp,
     int err, status=NC_NOERR;
     NC_bb_metadataheader* headerp;
 
-#ifdef PNETCDF_PROFILING
+#if defined(PNETCDF_PROFILING) && (PNETCDF_PROFILING == 1)
     unsigned long long total_data;
     unsigned long long total_meta;
     unsigned long long buffer_size;
@@ -420,7 +420,7 @@ int ncbbio_log_close(NC_bb *ncbbp,
         MPI_Comm_free(&(ncbbp->logcomm));
     }
 
-#ifdef PNETCDF_PROFILING
+#if defined(PNETCDF_PROFILING) && (PNETCDF_PROFILING == 1)
     t2 = MPI_Wtime();
     ncbbp->total_time += t2 - t1;
     ncbbp->close_time += t2 - t1;
@@ -497,7 +497,7 @@ int ncbbio_log_flush(NC_bb* ncbbp)
     int err, status = NC_NOERR;
     NC_bb_metadataheader *headerp;
 
-#ifdef PNETCDF_PROFILING
+#if defined(PNETCDF_PROFILING) && (PNETCDF_PROFILING == 1)
     double t1, t2;
     t1 = MPI_Wtime();
 #endif
@@ -547,7 +547,7 @@ int ncbbio_log_flush(NC_bb* ncbbp)
 
     ncbbp->datalogsize = 8;
 
-#ifdef PNETCDF_PROFILING
+#if defined(PNETCDF_PROFILING) && (PNETCDF_PROFILING == 1)
     t2 = MPI_Wtime();
     ncbbp->total_time += t2 - t1;
     ncbbp->flush_time += t2 - t1;
