@@ -50,8 +50,13 @@ ncmpio_read_write(NC           *ncp,
         /* return the first encountered error if there is any */
         err = (err == NC_EFILE) ? NC_EREAD : err;
     }
-    else if (btype_size == MPI_UNDEFINED)
+    else if (btype_size == MPI_UNDEFINED) {
+#ifdef PNETCDF_DEBUG
+        fprintf(stderr,"%d: %s line %d: btype_size MPI_UNDEFINED buf_count=%lld\n",
+                ncp->rank, __func__,__LINE__,buf_count);
+#endif
         DEBUG_ASSIGN_ERROR(err, NC_EINTOVERFLOW)
+    }
 
     if (err != NC_NOERR) {
         if (coll_indep == NC_REQ_COLL) {
@@ -85,12 +90,26 @@ ncmpio_read_write(NC           *ncp,
 
         if (buf_count > NC_MAX_INT) {
 #ifdef HAVE_MPI_LARGE_COUNT
-            MPI_Type_contiguous_c((MPI_Count)buf_count, buf_type, &xbuf_type);
+            mpireturn = MPI_Type_contiguous_c((MPI_Count)buf_count, buf_type, &xbuf_type);
+            if (mpireturn != MPI_SUCCESS) {
+                err = ncmpii_error_mpi2nc(mpireturn, "MPI_Type_contiguous_c");
+                if (coll_indep == NC_REQ_COLL)
+                    DEBUG_ASSIGN_ERROR(status, err)
+                else
+                    DEBUG_RETURN_ERROR(err)
+            }
             MPI_Type_commit(&xbuf_type);
             xlen = 1;
 #else
-            if (coll_indep == NC_REQ_COLL)
+            if (coll_indep == NC_REQ_COLL) {
+#ifdef PNETCDF_DEBUG
+                fprintf(stderr,"%d: %s line %d:  NC_EINTOVERFLOW buf_count=%lld\n",
+                        ncp->rank, __func__,__LINE__,buf_count);
+#endif
                 DEBUG_ASSIGN_ERROR(status, NC_EINTOVERFLOW)
+                /* write nothing, but participate the collective call */
+                xlen = 0;
+            }
             else
                 DEBUG_RETURN_ERROR(NC_EINTOVERFLOW)
 #endif
@@ -103,7 +122,14 @@ ncmpio_read_write(NC           *ncp,
              * noncontiguous.
              */
             if (req_size > NC_MAX_INT) {
-                MPI_Type_contiguous((int)buf_count, buf_type, &xbuf_type);
+                mpireturn = MPI_Type_contiguous((int)buf_count, buf_type, &xbuf_type);
+                if (mpireturn != MPI_SUCCESS) {
+                    err = ncmpii_error_mpi2nc(mpireturn, "MPI_Type_contiguous");
+                    if (coll_indep == NC_REQ_COLL)
+                        DEBUG_ASSIGN_ERROR(status, err)
+                    else
+                        DEBUG_RETURN_ERROR(err)
+                }
                 MPI_Type_commit(&xbuf_type);
                 xlen = 1;
             }
@@ -114,7 +140,7 @@ ncmpio_read_write(NC           *ncp,
             xbuf = NCI_Malloc((size_t)req_size);
         }
 
-        if (coll_indep == NC_REQ_COLL) {
+        if (ncp->nprocs > 1 && coll_indep == NC_REQ_COLL) {
             TRACE_IO(MPI_File_read_at_all)(fh, offset, xbuf, xlen, xbuf_type,
                                            &mpistatus);
             if (mpireturn != MPI_SUCCESS) {
@@ -165,13 +191,20 @@ ncmpio_read_write(NC           *ncp,
         if (xbuf != buf) { /* unpack contiguous xbuf to noncontiguous buf */
 #ifdef HAVE_MPI_LARGE_COUNT
             MPI_Count pos=0;
-            MPI_Unpack_c(xbuf, xlen, &pos, buf, (MPI_Count)buf_count, buf_type,
-                         MPI_COMM_SELF);
+            mpireturn = MPI_Unpack_c(xbuf, xlen, &pos, buf, (MPI_Count)buf_count,
+                                     buf_type, MPI_COMM_SELF);
 #else
             int pos=0;
-            MPI_Unpack(xbuf, xlen, &pos, buf, (int)buf_count, buf_type,
-                       MPI_COMM_SELF);
+            mpireturn = MPI_Unpack(xbuf, xlen, &pos, buf, (int)buf_count,
+                                   buf_type, MPI_COMM_SELF);
 #endif
+            if (mpireturn != MPI_SUCCESS) {
+                err = ncmpii_error_mpi2nc(mpireturn, "MPI_Unpack");
+                if (coll_indep == NC_REQ_COLL)
+                    DEBUG_ASSIGN_ERROR(status, err)
+                else
+                    DEBUG_RETURN_ERROR(err)
+            }
             NCI_Free(xbuf);
         }
         if (xbuf_type != buf_type && xbuf_type != MPI_BYTE)
@@ -183,12 +216,26 @@ ncmpio_read_write(NC           *ncp,
 
         if (buf_count > NC_MAX_INT) {
 #ifdef HAVE_MPI_LARGE_COUNT
-            MPI_Type_contiguous_c((MPI_Count)buf_count, buf_type, &xbuf_type);
+            mpireturn = MPI_Type_contiguous_c((MPI_Count)buf_count, buf_type, &xbuf_type);
+            if (mpireturn != MPI_SUCCESS) {
+                err = ncmpii_error_mpi2nc(mpireturn, "MPI_Type_contiguous_c");
+                if (coll_indep == NC_REQ_COLL)
+                    DEBUG_ASSIGN_ERROR(status, err)
+                else
+                    DEBUG_RETURN_ERROR(err)
+            }
             MPI_Type_commit(&xbuf_type);
             xlen = 1;
 #else
-            if (coll_indep == NC_REQ_COLL)
+            if (coll_indep == NC_REQ_COLL) {
+#ifdef PNETCDF_DEBUG
+                fprintf(stderr,"%d: %s line %d:  NC_EINTOVERFLOW buf_count=%lld\n",
+                        ncp->rank, __func__,__LINE__,buf_count);
+#endif
                 DEBUG_ASSIGN_ERROR(status, NC_EINTOVERFLOW)
+                /* write nothing, but participate the collective call */
+                xlen = 0;
+            }
             else
                 DEBUG_RETURN_ERROR(NC_EINTOVERFLOW)
 #endif
@@ -204,9 +251,25 @@ ncmpio_read_write(NC           *ncp,
 #ifdef HAVE_MPI_LARGE_COUNT
                 MPI_Count pos=0;
                 xbuf = NCI_Malloc(req_size);
-                MPI_Pack_c(buf, (MPI_Count)buf_count, buf_type, xbuf,
-                           (MPI_Count)req_size, &pos, MPI_COMM_SELF);
-                MPI_Type_contiguous_c((MPI_Count)req_size, MPI_BYTE, &xbuf_type);
+                mpireturn = MPI_Pack_c(buf, (MPI_Count)buf_count, buf_type, xbuf,
+                                       (MPI_Count)req_size, &pos, MPI_COMM_SELF);
+                if (mpireturn != MPI_SUCCESS) {
+                    err = ncmpii_error_mpi2nc(mpireturn, "MPI_Pack_c");
+                    if (coll_indep == NC_REQ_COLL)
+                        DEBUG_ASSIGN_ERROR(status, err)
+                    else
+                        DEBUG_RETURN_ERROR(err)
+                }
+                mpireturn = MPI_Type_contiguous_c((MPI_Count)req_size, MPI_BYTE, &xbuf_type);
+                if (mpireturn != MPI_SUCCESS) {
+                    err = ncmpii_error_mpi2nc(mpireturn, "MPI_Type_contiguous_c");
+                    if (coll_indep == NC_REQ_COLL) {
+                        DEBUG_ASSIGN_ERROR(status, err)
+                        xlen = 0;
+                    }
+                    else
+                        DEBUG_RETURN_ERROR(err)
+                }
                 MPI_Type_commit(&xbuf_type);
                 xlen = 1;
 #else
@@ -219,13 +282,20 @@ ncmpio_read_write(NC           *ncp,
                 int pos=0;
                 xlen = (int)req_size;
                 xbuf = NCI_Malloc(xlen);
-                MPI_Pack(buf, (int)buf_count, buf_type, xbuf, xlen, &pos,
-                         MPI_COMM_SELF);
+                mpireturn = MPI_Pack(buf, (int)buf_count, buf_type, xbuf,
+                                     xlen, &pos, MPI_COMM_SELF);
+                if (mpireturn != MPI_SUCCESS) {
+                    err = ncmpii_error_mpi2nc(mpireturn, "MPI_Pack");
+                    if (coll_indep == NC_REQ_COLL)
+                        DEBUG_ASSIGN_ERROR(status, err)
+                    else
+                        DEBUG_RETURN_ERROR(err)
+                }
                 xbuf_type = MPI_BYTE;
             }
         }
 
-        if (coll_indep == NC_REQ_COLL) {
+        if (ncp->nprocs > 1 && coll_indep == NC_REQ_COLL) {
             TRACE_IO(MPI_File_write_at_all)(fh, offset, xbuf, xlen, xbuf_type,
                                             &mpistatus);
             if (mpireturn != MPI_SUCCESS) {
