@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 #
 # Copyright (C) 2018, Northwestern University and Argonne National Laboratory
 # See COPYRIGHT notice in top-level directory.
@@ -29,8 +29,14 @@ fi
 unset PNETCDF_HINTS
 
 for j in ${safe_modes} ; do
+for intra_aggr in 0 1 ; do
     if test "$j" = 1 ; then # test only in safe mode
        export PNETCDF_HINTS="romio_no_indep_rw=true"
+    else
+       export PNETCDF_HINTS=
+    fi
+    if test "$intra_aggr" = 1 ; then
+       export PNETCDF_HINTS="${PNETCDF_HINTS};nc_num_aggrs_per_node=2"
     fi
     export PNETCDF_SAFE_MODE=$j
     # echo "set PNETCDF_SAFE_MODE ${PNETCDF_SAFE_MODE}"
@@ -63,6 +69,7 @@ for j in ${safe_modes} ; do
        # ${MPIRUN} ${NCMPIDIFF} -q ${TESTOUTDIR}/dim_cdf12.nc ${TESTOUTDIR}/dim_cdf12.bb.nc
     fi
 done
+done
 
 rm -f ${OUTDIR}/dim_cdf12.nc
 rm -f ${OUTDIR}/cdf_type.nc
