@@ -86,7 +86,7 @@ int main(int argc, char** argv) {
 
     nelms = (NRECS > DIMLEN) ? NRECS : DIMLEN;
     for (i=1; i<NDIMS; i++) nelms *= DIMLEN;
-    buffer = (short*) malloc(nelms * sizeof(short));
+    buffer = (short*) malloc(sizeof(short) * nelms);
     if (buffer == NULL) {
         printf("Error %s at line %d: fail to allocate buffer of size %zu\n",
                argv[0], __LINE__, nelms * sizeof(int));
@@ -182,6 +182,7 @@ fn_exit:
             printf("heap memory allocated by PnetCDF internally has %lld bytes yet to be freed\n",
                    sum_size);
     }
+    if (malloc_size > 0)  ncmpi_inq_malloc_list();
 #endif
     MPI_Allreduce(MPI_IN_PLACE, &nerrs, 1, MPI_INT, MPI_SUM, MPI_COMM_WORLD);
     if (rank == 0) {
