@@ -9,6 +9,9 @@ set -e
 
 outfile=`basename $1`
 
+# remove file system type prefix if there is any
+OUTDIR=`echo "$TESTOUTDIR" | cut -d: -f2-`
+
 # echo "PNETCDF_DEBUG = ${PNETCDF_DEBUG}"
 if test ${PNETCDF_DEBUG} = 1 ; then
    safe_modes="0 1"
@@ -16,9 +19,15 @@ else
    safe_modes="0"
 fi
 
+# prevent user environment setting of PNETCDF_HINTS to interfere
+unset PNETCDF_HINTS
+
 for j in ${safe_modes} ; do
     export PNETCDF_SAFE_MODE=$j
     # echo "set PNETCDF_SAFE_MODE ${PNETCDF_SAFE_MODE}"
     ${TESTSEQRUN} $1 ${TESTOUTDIR}/$outfile.nc
 done
 
+rm -f ${OUTDIR}/$outfile.nc
+rm -f ${OUTDIR}/$outfile.nc.cdf4
+
