@@ -121,7 +121,7 @@ int clear_file_contents(int ncid, int *varid)
 {
     int i, err, rank, nerrs=0;
     MPI_Offset start[2], count[2];
-    long long *w_buffer = (long long*) malloc(NY*NX * sizeof(long long));
+    long long *w_buffer = (long long*) malloc(sizeof(long long) * NY*NX);
 
     for (i=0; i<NY*NX; i++) w_buffer[i] = -1;
 
@@ -173,7 +173,7 @@ int check_contents_for_fail(int ncid, int *varid)
                                      12, 12, 13, 10, 10, 10, 11, 11, 12, 12,
                                      11, 11, 11, 13, 12, 12, 12, 10, 10, 10}};
 
-    long long *r_buffer = (long long*) malloc(NY*NX * sizeof(long long));
+    long long *r_buffer = (long long*) malloc(sizeof(long long) * NY*NX);
 
     MPI_Comm_size(MPI_COMM_WORLD, &nprocs);
     if (nprocs > 4) MPI_Barrier(MPI_COMM_WORLD);
@@ -264,8 +264,8 @@ test_varn(int ncid, int rank, int *varid)
      */
 
     /* allocate space for starts and counts */
-    starts[0] = (MPI_Offset**) malloc(4 * 6 * sizeof(MPI_Offset*));
-    counts[0] = (MPI_Offset**) malloc(4 * 6 * sizeof(MPI_Offset*));
+    starts[0] = (MPI_Offset**) malloc(sizeof(MPI_Offset*) * 4 * 6);
+    counts[0] = (MPI_Offset**) malloc(sizeof(MPI_Offset*) * 4 * 6);
     starts[0][0] = (MPI_Offset*) calloc(4 * 6 * NDIMS, sizeof(MPI_Offset));
     counts[0][0] = (MPI_Offset*) calloc(4 * 6 * NDIMS, sizeof(MPI_Offset));
     for (i=1; i<4; i++) {
@@ -318,7 +318,7 @@ test_varn(int ncid, int rank, int *varid)
         }
 
         /* allocate I/O buffer and initialize its contents */
-        buffer[i] = (long long*) malloc(req_lens[i] * sizeof(long long));
+        buffer[i] = (long long*) malloc(sizeof(long long) * req_lens[i]);
         for (j=0; j<req_lens[i]; j++) buffer[i][j] = rank+10;
     }
 
@@ -351,7 +351,7 @@ test_varn(int ncid, int rank, int *varid)
     /* try with buffer being a single contiguous space */
     for (i=0; i<nreqs; i++) bufsize += req_lens[i];
     if (bufsize>0) {
-        cbuffer[0] = (long long*) malloc(bufsize * sizeof(long long));
+        cbuffer[0] = (long long*) malloc(sizeof(long long) * bufsize);
         for (i=1; i<nreqs; i++) cbuffer[i] = cbuffer[i-1] + req_lens[i-1];
         for (i=0; i<bufsize; i++) cbuffer[0][i] = rank+10;
     }
@@ -450,7 +450,7 @@ test_varn(int ncid, int rank, int *varid)
         MPI_Datatype buftype;
         MPI_Type_vector(req_lens[i], 1, 2, MPI_LONG_LONG, &buftype);
         MPI_Type_commit(&buftype);
-        buffer[i] = (long long*) malloc(req_lens[i] * 2 * sizeof(long long));
+        buffer[i] = (long long*) malloc(sizeof(long long) * req_lens[i] * 2);
         for (j=0; j<req_lens[i]*2; j++) buffer[i][j] = rank+10;
 
         err = ncmpi_iput_varn(ncid, varid[i], my_nsegs[i], starts[i],
@@ -624,8 +624,8 @@ int main(int argc, char** argv)
         if (rank == 0 && sum_size > 0) {
             printf("heap memory allocated by PnetCDF internally has %lld bytes yet to be freed\n",
                    sum_size);
-            ncmpi_inq_malloc_list();
         }
+        if (malloc_size > 0) ncmpi_inq_malloc_list();
     }
 
     MPI_Allreduce(MPI_IN_PLACE, &nerrs, 1, MPI_INT, MPI_SUM, MPI_COMM_WORLD);
