@@ -66,7 +66,7 @@ int main(int argc, char **argv) {
     err = ncmpi_def_var(ncid, "var", NC_INT, 2, dimid, &varid); CHECK_ERR
     err = ncmpi_enddef(ncid); CHECK_ERR
 
-    req = (int*) malloc(NUM_REQS * 2 * sizeof(int));
+    req = (int*) malloc(sizeof(int) * NUM_REQS * 2);
     status = req + NUM_REQS;
 
     buf = (int*) calloc(NUM_REQS * 6,  sizeof(int));
@@ -118,8 +118,8 @@ int main(int argc, char **argv) {
         if (rank == 0 && sum_size > 0) {
             printf("heap memory allocated by PnetCDF internally has %lld bytes yet to be freed\n",
                    sum_size);
-            ncmpi_inq_malloc_list();
         }
+        if (malloc_size > 0) ncmpi_inq_malloc_list();
     }
 
     MPI_Allreduce(MPI_IN_PLACE, &nerrs, 1, MPI_INT, MPI_SUM, MPI_COMM_WORLD);
