@@ -113,9 +113,9 @@ int ncmpi_diff(char *filename1, char *filename2)
 
     str[0] = '\0';
     err = ncmpi_open(comm, filename1, NC_NOWRITE, MPI_INFO_NULL, &ncid1);
-    CHECK_ERR
+    CHECK_ERROUT
     err = ncmpi_open(comm, filename2, NC_NOWRITE, MPI_INFO_NULL, &ncid2);
-    CHECK_ERR
+    CHECK_ERROUT
 
     /**
      * Inquire the dataset definitions of input dataset AND
@@ -182,8 +182,8 @@ int ncmpi_diff(char *filename1, char *filename2)
         CHECK_ERR
         err = ncmpi_inq_varndims(ncid2, i, &ndims2);
         CHECK_ERR
-        dimids1 = (int*) malloc(ndims1 * sizeof(int));
-        dimids2 = (int*) malloc(ndims2 * sizeof(int));
+        dimids1 = (int*) malloc(sizeof(int) * ndims1);
+        dimids2 = (int*) malloc(sizeof(int) * ndims2);
 
         err = ncmpi_inq_var(ncid1, i, name1, &type1, &ndims1, dimids1, &natts1);
         CHECK_ERR
@@ -262,7 +262,7 @@ int ncmpi_diff(char *filename1, char *filename2)
         CHECK_ERR
         shape = (MPI_Offset*) calloc(ndims1 * 2, sizeof(MPI_Offset));
         start = shape + ndims1;
-        dimids1 = (int*) malloc(ndims1 * sizeof(int));
+        dimids1 = (int*) malloc(sizeof(int) * ndims1);
 
         varsize = 1;
         err = ncmpi_inq_var(ncid1, i, name1, &type1, &ndims1, dimids1, &natts1);
@@ -295,6 +295,7 @@ int ncmpi_diff(char *filename1, char *filename2)
     err = ncmpi_close(ncid2);
     CHECK_ERR
 
+err_out:
     return nerrs;
 }
 
@@ -354,42 +355,42 @@ int main(int argc, char **argv)
 
     nvars = 4;
 
-    buf = (int **)malloc(nvars*sizeof(int*));
+    buf = (int **)malloc(sizeof(int*)*nvars);
     if (buf == NULL){
         printf("buf malloc error\n");
         nerrs++; goto fn_exit;
     }
-    bufcounts = (MPI_Offset *)malloc(nvars*sizeof(MPI_Offset));
+    bufcounts = (MPI_Offset *)malloc(sizeof(MPI_Offset)*nvars);
     if (bufcounts == NULL){
         printf("bufcounts malloc error\n");
         nerrs++; goto fn_exit;
     }
-    starts = (MPI_Offset **)malloc(nvars*sizeof(MPI_Offset *));
+    starts = (MPI_Offset **)malloc(sizeof(MPI_Offset*)*nvars);
     if (starts== NULL){
         printf("starts malloc error\n");
         nerrs++; goto fn_exit;
     }
-    counts = (MPI_Offset **)malloc(nvars*sizeof(MPI_Offset *));
+    counts = (MPI_Offset **)malloc(sizeof(MPI_Offset*)*nvars);
     if (counts == NULL){
         printf("counts malloc error\n");
         nerrs++; goto fn_exit;
     }
-    datatype_list = (MPI_Datatype*)malloc(nvars*sizeof(MPI_Datatype));
+    datatype_list = (MPI_Datatype*)malloc(sizeof(MPI_Datatype)*nvars);
     if (datatype_list == NULL){
         printf("counts malloc error\n");
         nerrs++; goto fn_exit;
     }
 
-    reqs = (int *)malloc(nvars*sizeof(int));
-    sts = (int *)malloc(nvars*sizeof(int));
+    reqs = (int *)malloc(sizeof(int)*nvars);
+    sts = (int *)malloc(sizeof(int)*nvars);
 
     for (i=0; i<nvars; i++) {
-        starts[i] = (MPI_Offset *)malloc(ndims*sizeof(MPI_Offset));
+        starts[i] = (MPI_Offset *)malloc(sizeof(MPI_Offset)*ndims);
         if (starts[i] == NULL){
             printf("starts[%d] malloc error\n", i);
             nerrs++; goto fn_exit;
         }
-        counts[i] = (MPI_Offset *)malloc(ndims*sizeof(MPI_Offset));
+        counts[i] = (MPI_Offset *)malloc(sizeof(MPI_Offset)*ndims);
         if (counts[i] == NULL){
             printf("counts[%d] malloc error\n", i);
             nerrs++; goto fn_exit;
@@ -402,6 +403,9 @@ int main(int argc, char **argv)
         bufcount *= length;
     }
     MPI_Dims_create(nprocs, ndims, array_of_psizes);
+    if (verbose)
+        printf("rank %d: array_of_psizes[3]=%d %d %d\n",
+               rank,array_of_psizes[0],array_of_psizes[1],array_of_psizes[2]);
 
     /* subarray in each process is len x len x len */
     for (i=0; i<ndims; i++)
@@ -413,25 +417,28 @@ int main(int argc, char **argv)
     rank_dim[0] =  rank / (array_of_psizes[2]  * array_of_psizes[1]);
     if (verbose)
         printf("rank %d: rank_dim[3]=%d %d %d\n",
-               rank,rank_dim[0],rank_dim[2],rank_dim[2]);
+               rank,rank_dim[0],rank_dim[1],rank_dim[2]);
 
     /* starting coordinates of the subarray in each dimension */
     for (i=0; i<ndims; i++)
         array_of_starts[i] = length * rank_dim[i];
+    if (verbose)
+        printf("rank %d: array_of_starts[3]=%lld %lld %lld\n",
+               rank,array_of_starts[0],array_of_starts[1],array_of_starts[2]);
 
     for (i=0; i<nvars; i++) {
         for (j=0; j<ndims; j++) {
            starts[i][j] = array_of_starts[j];
-           counts[i][j]  = length;
+           counts[i][j] = length;
         }
         bufcounts[i] = bufcount;
         datatype_list[i] = MPI_INT;
     }
     if (verbose)
         printf("rank %d: starts[0][3]=%lld %lld %lld counts[0][3]=%lld %lld %lld\n",
-               rank,starts[0][0],starts[0][2],starts[0][2], counts[0][0],counts[0][1],counts[0][2]);
+               rank,starts[0][0],starts[0][1],starts[0][2], counts[0][0],counts[0][1],counts[0][2]);
 
-    buf[0] = (int *) malloc(bufcount * nvars * sizeof(int));
+    buf[0] = (int *) malloc(sizeof(int) * bufcount * nvars);
     if (buf[0] == NULL) {
         printf("buf[i]malloc error\n");
         nerrs++; goto fn_exit;
@@ -442,12 +449,12 @@ int main(int argc, char **argv)
         for (j=0; j<bufcount; j++)
             buf[i][j]=rank+1;
     }
-    buf_var = (int *) malloc(bufcount*nprocs*sizeof(int));
+    buf_var = (int *) malloc(sizeof(int)*bufcount*nprocs);
     for (i=0; i<bufcount*nprocs; i++)
         buf_var[i] = rank + 1;
 
     nvars2 = (nvars > nprocs) ? nvars : nprocs;
-    varid = (int *)malloc(nvars2*sizeof(int));
+    varid = (int *)malloc(sizeof(int)*nvars2);
     if (varid == NULL){
         printf("varid malloc error\n");
         nerrs++; goto fn_exit;
@@ -715,8 +722,8 @@ printf("filename2=%s filename3=%s\n",filename2, filename3);
         if (rank == 0 && sum_size > 0) {
             printf("heap memory allocated by PnetCDF internally has %lld bytes yet to be freed\n",
                    sum_size);
-            ncmpi_inq_malloc_list();
         }
+        if (malloc_size > 0) ncmpi_inq_malloc_list();
     }
 
     MPI_Allreduce(MPI_IN_PLACE, &nerrs, 1, MPI_INT, MPI_SUM, MPI_COMM_WORLD);
