@@ -64,7 +64,8 @@ int main(int argc, char** argv) {
 
     /* create a new file for writing ----------------------------------------*/
     cmode = NC_CLOBBER | NC_64BIT_DATA;
-    err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, info, &ncid); CHECK_ERR
+    err = ncmpi_create(MPI_COMM_WORLD, filename, cmode, info, &ncid);
+    CHECK_ERROUT
 
     /* define dimension */
     err = ncmpi_def_dim(ncid, "Y", NC_UNLIMITED, &dimid[0]); CHECK_ERR
@@ -90,7 +91,7 @@ int main(int argc, char** argv) {
     err = ncmpi_enddef(ncid); CHECK_ERR
 
     /* write all variables */
-    buf = (int*) malloc(NX * sizeof(int));
+    buf = (int*) malloc(sizeof(int) * NX);
     for (i=0; i<NVARS; i++) {
         for (j=0; j<NX; j++) buf[j] = rank*1000 + i*10 + j;
 #ifdef TEST_FIXED_VAR
@@ -133,11 +134,11 @@ int main(int argc, char** argv) {
 
     /* mimic netCDF that does not do alignments */
     MPI_Info_create(&info);
-    MPI_Info_set(info, "nc_header_align_size", "1"); /* size in bytes */
-    MPI_Info_set(info, "nc_var_align_size",    "197"); /* size in bytes */
+    MPI_Info_set(info, "nc_var_align_size", "197"); /* size in bytes */
 
     /* open the file for adding more metadata */
-    err = ncmpi_open(MPI_COMM_WORLD, filename, NC_WRITE, info, &ncid); CHECK_ERR
+    err = ncmpi_open(MPI_COMM_WORLD, filename, NC_WRITE, info, &ncid);
+    CHECK_ERROUT
 
     /* get header size and extent, and offsets of all variables */
     err = ncmpi_inq_header_size(ncid, &header_size[0]); CHECK_ERR
@@ -238,11 +239,12 @@ int main(int argc, char** argv) {
             start[0] = NX*rank;
             count[0] = NX;
             err = ncmpi_put_vara_int_all(ncid, new_varid[i], start, count, buf); CHECK_ERR
+            sprintf(str,"fixed_var_%d",i);
             /* check if user put buffer contents altered */
             for (j=0; j<NX; j++) {
                 if (buf[j] != -1 * (i*10 + j)) {
-                    printf("Error at line %d in %s: user put buffer[%d] altered from %d to %d\n",
-                           __LINE__,__FILE__,j, -1 * (i*10 + j), buf[j]);
+                    printf("Error at %d in %s: var %s put buffer[%d] altered from %d to %d\n",
+                           __LINE__,__FILE__, str, j, -1 * (i*10 + j), buf[j]);
                     nerrs++;
                 }
             }
@@ -256,11 +258,12 @@ int main(int argc, char** argv) {
             for (j=0; j<NX; j++) buf[j] = -1 * (100 + i*10 + j);
             start[0] = 1; /* write 2nd record */
             err = ncmpi_put_vara_int_all(ncid, new_varid[i], start, count, buf); CHECK_ERR
+            sprintf(str,"record_var_%d",i);
             /* check if user put buffer contents altered */
             for (j=0; j<NX; j++) {
                 if (buf[j] != -1 * (100 + i*10 + j)) {
-                    printf("Error at line %d in %s: user put buffer[%d] altered from %d to %d\n",
-                           __LINE__,__FILE__,j, -1 * (100 + i*10 + j), buf[j]);
+                    printf("Error at %d in %s: var %s put buffer[%d] altered from %d to %d\n",
+                           __LINE__,__FILE__, str, j, -1 * (100 + i*10 + j), buf[j]);
                     nerrs++;
                 }
             }
@@ -274,11 +277,15 @@ int main(int argc, char** argv) {
         if (i%2) {
             start[0] = NX*rank;
             count[0] = NX;
+            for (j=0; j<NX; j++) buf[j] = -1;
             err = ncmpi_get_vara_int_all(ncid, varid[i], start, count, buf); CHECK_ERR
+            sprintf(str,"fixed_var_%d",i);
             for (j=0; j<NX; j++)
                 if (buf[j] != rank*1000 + i*10 + j) {
-                    printf("read error i=%d buf[j=%d]=%d != %d\n",i,j,buf[j],rank*1000+i*10+j);
+                    printf("Error at %d: var %s i=%d buf[j=%d]=%d != %d\n",
+                           __LINE__,str,i,j,buf[j],rank*1000+i*10+j);
                     nerrs++;
+                    break;
                 }
         }
 #endif
@@ -289,15 +296,19 @@ int main(int argc, char** argv) {
             err = ncmpi_get_vara_int_all(ncid, varid[i], start, count, buf); CHECK_ERR
             for (j=0; j<NX; j++)
                 if (buf[j] != rank*1000+i*10+j) {
-                    printf("read error i=%d buf[j=%d]=%d != %d\n",i,j,buf[j],rank*1000+i*10+j);
+                    printf("read error at %d: i=%d buf[j=%d]=%d != %d\n",__LINE__,i,j,buf[j],rank*1000+i*10+j);
                     nerrs++;
+                    break;
                 }
             start[0] = 1;
             err = ncmpi_get_vara_int_all(ncid, varid[i], start, count, buf); CHECK_ERR
+            sprintf(str,"record_var_%d",i);
             for (j=0; j<NX; j++)
                 if (buf[j] != rank*1000 + 100 + i*10 + j) {
-                    printf("read error i=%d buf[j=%d]=%d != %d\n",i,j,buf[j],rank*1000+100+i*10+j);
+                    printf("Error at %d: var %s i=%d buf[j=%d]=%d != %d\n",
+                           __LINE__, str,i,j,buf[j],rank*1000+100+i*10+j);
                     nerrs++;
+                    break;
                 }
         }
 #endif
@@ -323,6 +334,7 @@ int main(int argc, char** argv) {
         else       printf(PASS_STR);
     }
 
+err_out:
     MPI_Finalize();
     return (nerrs > 0);
 }
