@@ -9,6 +9,9 @@ set -e
 
 VALIDATOR=../../src/utils/ncvalidator/ncvalidator
 
+# prevent user environment setting of PNETCDF_HINTS to interfere
+unset PNETCDF_HINTS
+
 ${TESTSEQRUN} ./tst_version
 
 ${TESTSEQRUN} ./put_all_kinds ${TESTOUTDIR}/put_all_kinds.nc
@@ -34,11 +37,15 @@ ${TESTSEQRUN} ${NCMPIDIFF} -q ${TESTOUTDIR}/testfile.nc ${TESTOUTDIR}/redef1.nc
 # diff -q ${OUT_PATH}/testfile.nc ${OUT_PATH}/redef1.nc
 
 ${TESTSEQRUN} ${VALIDATOR} -q ${TESTOUTDIR}/testfile.nc
+rm -f ${OUT_PATH}/redef1.nc
+rm -f ${OUT_PATH}/testfile.nc
 
 # echo ""
 
 if test "x${ENABLE_BURST_BUFFER}" = x1 ; then
-   # echo "---- testing burst buffering"
+   echo ""
+   echo "---- testing burst buffering"
+
    # Run using burst buffer driver
    export PNETCDF_HINTS="nc_burst_buf=enable;nc_burst_buf_dirname=${TESTOUTDIR};nc_burst_buf_overwrite=enable"
    ${TESTSEQRUN} ./put_all_kinds ${TESTOUTDIR}/put_all_kinds.bb.nc
@@ -51,6 +58,10 @@ if test "x${ENABLE_BURST_BUFFER}" = x1 ; then
        ${TESTSEQRUN} ${NCMPIDIFF} -q ${TESTOUTDIR}/iput_all_kinds.nc$i ${TESTOUTDIR}/iput_all_kinds.bb.nc$i
    done
 fi
+rm -f ${OUT_PATH}/put_all_kinds.nc*
+rm -f ${OUT_PATH}/put_all_kinds.bb.nc*
+rm -f ${OUT_PATH}/iput_all_kinds.nc*
+rm -f ${OUT_PATH}/iput_all_kinds.bb.nc*
 
 # echo ""
 
@@ -63,6 +74,7 @@ if test "${ENABLE_THREAD_SAFE}" = 1 ; then
        ${TESTSEQRUN} ./tst_pthread ${TESTOUTDIR}/tst_pthread.nc
        for i in 0 1 2 3 4 5 ; do
            ${TESTSEQRUN} ${VALIDATOR} -q ${TESTOUTDIR}/tst_pthread.nc.$i
+           rm -f ${OUT_PATH}/tst_pthread.nc.$i
        done
    done
 fi
